==> oddmuse-1.464.tar.gz: oddmuse-1.464/french-utf8.pl <==
# UTF-8 encoded French language file for use with Oddmuse
#
# Copyright (c) 2003  Pierre Gaston
# Copyright (c) 2004  Christophe Ducamp
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.296.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Accès interdit&nbsp;: votre serveur, adresse IP ou nom d'utilisateur a été bloqué.
Could not create %s
Création impossible de %s
Invalid UserName %s: not saved.
Nom d'utilisateur non valide %s&nbsp;: pas sauvegardé
UserName must be 50 characters or less: not saved
Le nom d'utilisateur ne doit pas dépasser 50 caractères&nbsp;: pas sauvegardé
XML::RSS is not available on this system.

diff
diff
history
historique
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 
 . . . . 
Click to edit this page

Invalid action parameter %s
Parmètre d'action invalide %s
Invalid URL.
URL non valide
Page name is missing

Page name is too long: %s
Nom de page trop long&nbsp;: %s
Invalid Page %s
Page non valide %s
Invalid Page %s (must not end with .db)
Page non valide %s (elle ne doit pas se terminer par .db)
Invalid Page %s (must not end with .lck)
Page non valide %s (elle ne doit pas se terminer par .lck)
Page name may not contain space characters: %s
Le nom de la page ne peut pas contenir d'espaces&nbsp;: %s
Preview:
Prévisualisation&nbsp;:
Preview only, not yet saved
Prévisualisation seulement, pas encore sauvegardée
Please go on to %s.
Svp aller a %s
Could not open %s log file
Impossible d'ouvrir le fichier de log %
Error was
L'erreur était
Note: This error is normal if no changes have been made.
Remarque&nbsp;: Cette erreur est normale si aucune modification n'a été effectuée.
Could not open old %s log file
Impossible d'ouvrir l'ancien fichier de log %
No updates since %s
Aucune mise à jour depuis le %s
Updates since %s
Mises à hour depuis %s
Updates in the last %s days
Mises à jour durant les derniers %s jours
Updates in the last %s day
Mises à jour durant le dernier %s jour
for %s only
pour %s seulement
List latest change per page only
Lister seulement les dernières modifications par page
List all changes
Lister toutes les modifications
List only major changes
Lister seulement les modifications majeures
Include minor changes
Inclure les modifications mineures
%s days
%s jours
List later changes
Lister les modifications les plus récentes
Filters
Filtres
Username:
Nom d'utilisateur&nbsp;:
Host:
Hôte&nbsp;:
Language:
Langue&nbsp;:
Go!
Aller !
(minor)
(mineur)
rollback

new

from %s
depuis %s
History of %s
Historique de %s
Compare
Comparaison
Revision %s
Version %s
by
par
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]
[Accueil]
redirected from %s
redirigée à partir de %s
Click to search for references to this page
Cliquer pour chercher des références vers cette page
Cookie: 
Cookie&nbsp;: 
Warning
ATTENTION
Database is stored in temporary directory %s
Base de données stockée dans le répertoire temporaire %s
%s seconds
%s secondes
The same page on other sites:

EditNearLinks

Last edited
Dernière modification
Edited
Modifié
by %s
par %s
(diff)
(diff)
Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
Commentaires sur cette page
Edit revision %s of this page
Modifier la version %s de cette page
Edit text of this page
Modifier le texte de cette page
e

This page is read-only
Cette page est en lecture seule
View other revisions
Voir les autres versions
View current revision
Voir la version actuelle
View all changes
Voir toutes les modifications
Back to %s

new comment
nouveau commentaire
s

Save
Sauvegarder
Preview
Prévisualisation
Search:
Rechercher&nbsp;:
Replace:
Remplacer&nbsp;:
Validate HTML
Validation du HTML
Validate CSS
Validation des CSS
Difference (from revision %1 to %2)
Différence (de la révision %1 à %2)
revision %s
Version %s
current revision
version actuelle
Difference (from prior %s revision)
Différences (à partir des dernières versions %s)
major
majeure
minor
mineure
No diff available.
Pas de diff disponible.
Changed:
Modifiée&nbsp;:
Removed:
Suprimée&nbsp;:
Added:
Ajoutée&nbsp;:
to
à
Revision %s not available
La version %s n'est pas disponible
showing current revision instead
Présentation de la version en cours à sa place.
Showing revision %s
Présentation de la version %s
Cannot save an nameless page.
Ne peut pas sauvegarder une page sans nom
Cannot open %s
Ne peut ouvrir %s
Cannot write %s
Ne peut écrire %s
Could not get %s lock
Ne peut obtenir un verrouillage %s
Unlocking
Supression du verrou
This operation may take several seconds...
Cette opération peut prendre quelques secondes...
Forced unlock of %s lock.
Supression forcée du verrou %s.
No unlock required.
La suppression du verrou n'est pas nécessaire.
%s hours ago
il y a %s heures
1 hour ago
il y a une heure
%s minutes ago
il y a %s minutes
1 minute ago
il y a une minute
%s seconds ago
il y a %s secondes
1 second ago
il y a 1 seconde
just now
à l'instant
Editing Denied
Modification interdite
Editing not allowed: user, ip, or network is blocked.
Modification interdite&nbsp;: l'utilisateur, l'adresse ip, ou le reseau est bloqué
Contact the wiki administrator for more information.
Contactez l'administrateur du wiki pour plus d'information.
The rule %s matched for you.
La règle %s a fonctionné pour vous.
See %s for more information.
Voir %s pour plus d'information
Editing not allowed: %s is read-only.
Modification interdite&nbsp;: %s est en lecture seule
Only administrators can upload files.
Seuls les administrateurs peuvent téléverser des fichiers.
Editing revision %s of
Modification de la version %s de
Editing %s
Modification de %s
Editing old revision %s.
Modification de l'ancienne version %s.
Saving this page will replace the latest revision with this text.
Sauvegarder cette page remplacera la dernière version par ce texte.
Summary:
Résumé&nbsp;:
This change is a minor edit.
Cette modification est mineure.
Replace this file with text.
Remplacer ce fichier par un texte.
Replace this text with a file.
Remplacer ce texte par un fichier.
File to upload: 
Fichier à téléverser&nbsp;: 
Files of type %s are not allowed.
Les fichiers de type %s ne sont pas autorisés.
Password
Mot de passe
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Votre mot de passe est conservé dans un cookie, si cette fonctionnalité est activée dans votre navigateur. Les cookies peuvent être perdus si vous vous reconnectez d'une autre machine, d'un autre compte ou en utilisant un autre logiciel.
You are currently an administrator on this site.
Vous êtes actuellement administrateur de ce site.
You are currently an editor on this site.
Vous êtes actuellement éditeur de ce site.
You are a normal user on this site.
Vous êtes un utilisateur normal sur ce site.
Your password does not match any of the  administrator or editor passwords.
Vote mot de passe ne corespond à aucun de ceux des administrateurs ou éditeurs.
Password:
Mot de passe&nbsp;:
This site does not use admin or editor passwords.
Ce site n'utilise pas de mot de passe pour les administrateurs ou les éditeurs.
This operation is restricted to site editors only...
Cette opération est réservée aux éditeurs du site seulement...
This operation is restricted to administrators only...
Cette opération est réservée aux administrateurs seulement...
Rule "%1" matched "%2" on this page.

Index of all pages
Index de toutes les pages
all pages
toutes les pages
permanent anchors
ancres permanentes
near links

(for %s)
(pour %s)
%s pages found.
%s pages trouvées.
Replaced: %s
Remplacé&nbsp;: %s
Search for: %s
Rechercher&nbsp;: %s
View changes for these pages
Voir les modifications pour ces pages
Search sites on the %s as well

and
et
or
ou
Fetching results from %s:

Near pages:

last updated
dernière mise à jour
Complete Content
Contenu Complet
The main page is %s.
La page principale est %s.
Editing not allowed for %s.
Edition non autorisée pour %s.
SampleUndefinedPage
ExempleDePageNonDefinie
%s cannot be defined.
%s ne peut être défini.
Sample_Undefined_Page
Exemple_De_Page_NonDefinie
[[%s]] cannot be defined.
[[%s]] ne peut être défini.
Only an administrator can create %s.

Transfer Error: %s
Erreur de Transfert&nbsp;: %s
Browser reports no file info.
Le navigateur signale pas d'information sur le fichier.
Browser reports no file type.
Le navigateur signale pas de format de fichier.
Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Cette page a été modifiée par quelqu'un d'autre %s.
The changes conflict.  Please check the page again.
Conflit sur les modifications. SVP vérifiez la page à nouveau.
Please check whether you overwrote those changes.
SVP vérifiez si vous écrasez ces modifications.
Anonymous
Anonyme
Could not get a lock to merge!
Ne peut pas obtenir un verrou pour la fusion !
you
vous
ancestor
ancêtre
other
autre
Maintenance on all pages
Maintenance sur toutes les pages
Maintenance not done.
Maintenance non effectuée.
(Maintenance can only be done once every 12 hours.)
(La maintenance ne peut être effectuée qu'une fois toutes les 12 heures.)
Remove the "maintain" file or wait.
Enlevez le fichier "maintain" ou patientez.
Main lock obtained.
Verrou principal obtenu.
Expiring keep files and deleting pages marked for deletion
Expiration des fichiers de cache et suppression des pages marquées pour la suppression
not deleted: 

deleted
supprimé
Moving part of the %s log file.
Deplace une partie du fichier de log %s.
Moving %s log entries.
Déplace %s entrées du log.
Getting page index file for %s.

Main lock released.
Verrou principal rendu.
Set or Remove global edit lock
Positionne ou Enlève le verrou global d'édition
Edit lock created.
Verrou d'édition créé.
Edit lock removed.
Verrou d'édition enlevé.
Set or Remove page edit lock
Positionne ou enlève le verrou d'édition de la page
Missing page id to lock/unlock...
Id de page manquant pour verrouiller/déverrouiller...
Lock for %s created.
Verrou pour %s créé.
Lock for %s removed.
Verrou pour %s enlevé.
Displaying Wiki Version
Affiche la version du wiki
Inter links:

Near links:

Too many connections by %s
Trop de connexions par %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Recent Visitors
Derniers Visiteurs
Referrers
Introducteurs
All Referrers
Tous les Introducteurs
anchor first defined here: %s
première ancre définie ici&nbsp;: %s
Click to search for references to this permanent anchor
Cliquer pour chercher des références vers cette ancre permanente
the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Footnotes:

image: %s

Index

Languages:

Show!

Define

Full Link List
Liste Complète des Liens
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

Static Copy

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.fr/exec/obidos/ISBN=%s
alternate
Alternative
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
Recherche
Blog

END_OF_TRANSLATION

==> oddmuse-1.524.tar.gz: oddmuse-1.524/french-utf8.pl <==
# UTF-8 encoded French language file for use with Oddmuse
#
# Copyright (c) 2003  Pierre Gaston
# Copyright (c) 2004  Christophe Ducamp
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.296.
#
$ModulesDescription .= '<p>$Id: french-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Accès interdit&nbsp;: votre serveur, adresse IP ou nom d'utilisateur a été bloqué.
Could not create %s
Création impossible de %s
Invalid UserName %s: not saved.
Nom d'utilisateur non valide %s&nbsp;: pas sauvegardé
UserName must be 50 characters or less: not saved
Le nom d'utilisateur ne doit pas dépasser 50 caractères&nbsp;: pas sauvegardé
This page contains an uploaded file:

XML::RSS is not available on this system.

diff
diff
history
historique
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 
 . . . . 
Click to edit this page

image

download

Invalid action parameter %s
Parmètre d'action invalide %s
Invalid URL.
URL non valide
Page name is missing

Page name is too long: %s
Nom de page trop long&nbsp;: %s
Invalid Page %s
Page non valide %s
Invalid Page %s (must not end with .db)
Page non valide %s (elle ne doit pas se terminer par .db)
Invalid Page %s (must not end with .lck)
Page non valide %s (elle ne doit pas se terminer par .lck)
Page name may not contain space characters: %s
Le nom de la page ne peut pas contenir d'espaces&nbsp;: %s
Preview:
Prévisualisation&nbsp;:
Preview only, not yet saved
Prévisualisation seulement, pas encore sauvegardée
Please go on to %s.
Svp aller a %s
Could not open %s log file
Impossible d'ouvrir le fichier de log %
Error was
L'erreur était
Note: This error is normal if no changes have been made.
Remarque&nbsp;: Cette erreur est normale si aucune modification n'a été effectuée.
Could not open old %s log file
Impossible d'ouvrir l'ancien fichier de log %
No updates since %s
Aucune mise à jour depuis le %s
Updates since %s
Mises à hour depuis %s
Updates in the last %s days
Mises à jour durant les derniers %s jours
Updates in the last %s day
Mises à jour durant le dernier %s jour
for %s only
pour %s seulement
List latest change per page only
Lister seulement les dernières modifications par page
List all changes
Lister toutes les modifications
List only major changes
Lister seulement les modifications majeures
Include minor changes
Inclure les modifications mineures
%s days
%s jours
List later changes
Lister les modifications les plus récentes
Filters
Filtres
Username:
Nom d'utilisateur&nbsp;:
Host:
Hôte&nbsp;:
Language:
Langue&nbsp;:
Go!
Aller !
(minor)
(mineur)
rollback

new

from %s
depuis %s
History of %s
Historique de %s
Compare
Comparaison
Revision %s
Version %s
by
par
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Index de toutes les pages
Wiki Version
Affiche la version du wiki
Unlock Wiki
Supression du verrou
Recent Visitors
Derniers Visiteurs
Password
Mot de passe
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Accueil]
redirected from %s
redirigée à partir de %s
Click to search for references to this page
Cliquer pour chercher des références vers cette page
Cookie: 
Cookie&nbsp;: 
Warning
ATTENTION
Database is stored in temporary directory %s
Base de données stockée dans le répertoire temporaire %s
%s seconds
%s secondes
The same page on other sites:

EditNearLinks

Last edited
Dernière modification
Edited
Modifié
by %s
par %s
(diff)
(diff)
Edit revision %s of this page
Modifier la version %s de cette page
Edit this page
Modifier cette page
e

This page is read-only
Cette page est en lecture seule
View other revisions
Voir les autres versions
View current revision
Voir la version actuelle
View all changes
Voir toutes les modifications
new comment
nouveau commentaire
Homepage URL:

s

Save
Sauvegarder
Preview
Prévisualisation
Search:
Rechercher&nbsp;:
f

Replace:
Remplacer&nbsp;:
Validate HTML
Validation du HTML
Validate CSS
Validation des CSS
Difference (from revision %1 to %2)
Différence (de la révision %1 à %2)
revision %s
Version %s
current revision
version actuelle
Difference (from prior %s revision)
Différences (à partir des dernières versions %s)
major
majeure
minor
mineure
No diff available.
Pas de diff disponible.
Old revision:

Changed:
Modifiée&nbsp;:
Removed:
Suprimée&nbsp;:
Added:
Ajoutée&nbsp;:
to
à
Revision %s not available
La version %s n'est pas disponible
showing current revision instead
Présentation de la version en cours à sa place.
Showing revision %s
Présentation de la version %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s
Ne peut ouvrir %s
Cannot write %s
Ne peut écrire %s
Could not get %s lock
Ne peut obtenir un verrouillage %s
This operation may take several seconds...
Cette opération peut prendre quelques secondes...
Forced unlock of %s lock.
Supression forcée du verrou %s.
No unlock required.
La suppression du verrou n'est pas nécessaire.
%s hours ago
il y a %s heures
1 hour ago
il y a une heure
%s minutes ago
il y a %s minutes
1 minute ago
il y a une minute
%s seconds ago
il y a %s secondes
1 second ago
il y a 1 seconde
just now
à l'instant
Editing Denied
Modification interdite
Editing not allowed: user, ip, or network is blocked.
Modification interdite&nbsp;: l'utilisateur, l'adresse ip, ou le reseau est bloqué
Contact the wiki administrator for more information.
Contactez l'administrateur du wiki pour plus d'information.
The rule %s matched for you.
La règle %s a fonctionné pour vous.
See %s for more information.
Voir %s pour plus d'information
Editing not allowed: %s is read-only.
Modification interdite&nbsp;: %s est en lecture seule
Only administrators can upload files.
Seuls les administrateurs peuvent téléverser des fichiers.
Editing revision %s of
Modification de la version %s de
Editing %s
Modification de %s
Editing old revision %s.
Modification de l'ancienne version %s.
Saving this page will replace the latest revision with this text.
Sauvegarder cette page remplacera la dernière version par ce texte.
Summary:
Résumé&nbsp;:
This change is a minor edit.
Cette modification est mineure.
Replace this file with text.
Remplacer ce fichier par un texte.
Replace this text with a file.
Remplacer ce texte par un fichier.
File to upload: 
Fichier à téléverser&nbsp;: 
Files of type %s are not allowed.
Les fichiers de type %s ne sont pas autorisés.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Votre mot de passe est conservé dans un cookie, si cette fonctionnalité est activée dans votre navigateur. Les cookies peuvent être perdus si vous vous reconnectez d'une autre machine, d'un autre compte ou en utilisant un autre logiciel.
You are currently an administrator on this site.
Vous êtes actuellement administrateur de ce site.
You are currently an editor on this site.
Vous êtes actuellement éditeur de ce site.
You are a normal user on this site.
Vous êtes un utilisateur normal sur ce site.
Your password does not match any of the  administrator or editor passwords.
Vote mot de passe ne corespond à aucun de ceux des administrateurs ou éditeurs.
Password:
Mot de passe&nbsp;:
This site does not use admin or editor passwords.
Ce site n'utilise pas de mot de passe pour les administrateurs ou les éditeurs.
This operation is restricted to site editors only...
Cette opération est réservée aux éditeurs du site seulement...
This operation is restricted to administrators only...
Cette opération est réservée aux administrateurs seulement...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(pour %s)
%s pages found.
%s pages trouvées.
Replaced: %s
Remplacé&nbsp;: %s
Search for: %s
Rechercher&nbsp;: %s
View changes for these pages
Voir les modifications pour ces pages
Search sites on the %s as well

and
et
or
ou
Fetching results from %s:

Near pages:

last updated
dernière mise à jour
Complete Content
Contenu Complet
The main page is %s.
La page principale est %s.
Comments on this page
Commentaires sur cette page
Editing not allowed for %s.
Edition non autorisée pour %s.
SampleUndefinedPage
ExempleDePageNonDefinie
%s cannot be defined.
%s ne peut être défini.
Sample_Undefined_Page
Exemple_De_Page_NonDefinie
[[%s]] cannot be defined.
[[%s]] ne peut être défini.
Only an administrator can create %s.

Transfer Error: %s
Erreur de Transfert&nbsp;: %s
Browser reports no file info.
Le navigateur signale pas d'information sur le fichier.
Browser reports no file type.
Le navigateur signale pas de format de fichier.
Edit Denied

The page contains banned text.

This page was changed by somebody else %s.
Cette page a été modifiée par quelqu'un d'autre %s.
The changes conflict.  Please check the page again.
Conflit sur les modifications. SVP vérifiez la page à nouveau.
Please check whether you overwrote those changes.
SVP vérifiez si vous écrasez ces modifications.
Anonymous
Anonyme
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
Ne peut pas obtenir un verrou pour la fusion !
you
vous
ancestor
ancêtre
other
autre
Run Maintenance

Maintenance not done.
Maintenance non effectuée.
(Maintenance can only be done once every 12 hours.)
(La maintenance ne peut être effectuée qu'une fois toutes les 12 heures.)
Remove the "maintain" file or wait.
Enlevez le fichier "maintain" ou patientez.
Main lock obtained.
Verrou principal obtenu.
Expiring keep files and deleting pages marked for deletion
Expiration des fichiers de cache et suppression des pages marquées pour la suppression
not deleted: 

deleted
supprimé
Moving part of the %s log file.
Deplace une partie du fichier de log %s.
Moving %s log entries.
Déplace %s entrées du log.
Getting page index file for %s.

Main lock released.
Verrou principal rendu.
Set or Remove global edit lock
Positionne ou Enlève le verrou global d'édition
Edit lock created.
Verrou d'édition créé.
Edit lock removed.
Verrou d'édition enlevé.
Set or Remove page edit lock
Positionne ou enlève le verrou d'édition de la page
Missing page id to lock/unlock...
Id de page manquant pour verrouiller/déverrouiller...
Lock for %s created.
Verrou pour %s créé.
Lock for %s removed.
Verrou pour %s enlevé.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Trop de connexions par %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s
première ancre définie ici&nbsp;: %s
Click to search for references to this permanent anchor
Cliquer pour chercher des références vers cette ancre permanente
the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
Liste Complète des Liens
Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers
Tous les Introducteurs
Referrers
Introducteurs
Updating %s

Search term missing.

Static Copy

Back to %s

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.fr/exec/obidos/ISBN=%s
alternate
Alternative
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
Recherche
Blog

END_OF_TRANSLATION
